@@ -613,7 +613,7 @@ char** Sim::TraceNames(unsigned int* len)
 /* 
  * ToggleLinear:
  * 
- * dummy function for Corr 
+ * dumMY function for Corr 
  */
 
 void Sim::ToggleLinear(void)
@@ -624,7 +624,7 @@ void Sim::ToggleLinear(void)
 /* 
  * sum_b"
  * 
- * dummy function for Corr 
+ * dumMY function for Corr 
  */
 
 unsigned int Sim::sum_b(void)
@@ -633,6 +633,21 @@ unsigned int Sim::sum_b(void)
 }
 
 
+void Sim::Invert(unsigned int n)
+{
+
+  if(! linear) {
+    assert(n == this->n);
+    inverse_chol(K, Ki, Kchol, n);
+    log_det_K = log_determinant_chol(Kchol, n);
+  }
+  else {
+    assert(n > 0);
+    log_det_K = n * log(1.0 + nug);
+  }
+}
+
+
 /*
  * Sim_Prior:
  *
@@ -748,8 +763,8 @@ void Sim_Prior::read_double(double *dparams)
 
   /* read the starting value(s) for the range parameter(s) */
   for(unsigned int i=0; i<dim; i++) d[i] = dparams[1];
-  /*myprintf(mystdout, "starting d=");
-    printVector(d, dim, mystdout, HUMAN); */
+  /*MYprintf(MYstdout, "starting d=");
+    printVector(d, dim, MYstdout, HUMAN); */
 
   /* reset the d parameter to after nugget and gamlin params */
   dparams += 13;
@@ -765,7 +780,7 @@ void Sim_Prior::read_double(double *dparams)
 
   /* d hierarchical lambda prior parameters */
   if((int) dparams[0] == -1)
-    { fix_d = true; /*myprintf(mystdout, "fixing d prior\n");*/ }
+    { fix_d = true; /*MYprintf(MYstdout, "fixing d prior\n");*/ }
   else {
     fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, dparams, "d lambda");
@@ -791,7 +806,7 @@ void Sim_Prior::read_double(double *dparams)
   /* Choleski decompose */
   int info = linalg_dpotrf(dim, dp_cov_chol);
   assert(info == 0); 
-  if(info == 0) myprintf(mystdout, "bad Cholesky in read_double\n"); /* for NDEBUG */
+  if(info == 0) MYprintf(MYstdout, "bad Cholesky in read_double\n"); /* for NDEBUG */
 }
 
 
@@ -813,8 +828,8 @@ void Sim_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   d[0] = atof(strtok(line, " \t\n#"));
   for(unsigned int i=1; i<dim; i++) d[i] = d[0];
-  myprintf(mystdout, "starting d=", d);
-  printVector(d, dim, mystdout, HUMAN);
+  MYprintf(MYstdout, "starting d=", d);
+  printVector(d, dim, MYstdout, HUMAN);
 
   /* read d and nug-hierarchical parameters (mix of gammas) */
   double alpha[2], beta[2];
@@ -829,7 +844,7 @@ void Sim_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   strcpy(line_copy, line);
   if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
-    { fix_d = true; myprintf(mystdout, "fixing d prior\n"); }
+    { fix_d = true; MYprintf(MYstdout, "fixing d prior\n"); }
   else {
     fix_d = false;
     get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
@@ -1082,29 +1097,29 @@ void Sim_Prior::SetBasePrior(Base_Prior *base_prior)
 
 void Sim_Prior::Print(FILE *outfile)
 {
-  myprintf(mystdout, "corr prior: separable power\n");
+  MYprintf(MYstdout, "corr prior: separable power\n");
 
   /* print nugget stuff first */
   PrintNug(outfile);
 
   /* range parameter */
-  /* myprintf(outfile, "starting d=\n");
+  /* MYprintf(outfile, "starting d=\n");
      printVector(d, dim, outfile, HUMAN); */
 
   /* range gamma prior, just print once */
-  myprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n",
+  MYprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n",
 	   d_alpha[0][0], d_beta[0][0], d_alpha[0][1], d_beta[0][1]);
 
   /* print many times, one for each dimension instead? */
   /* for(unsigned int i=1; i<dim; i++) {
-       myprintf(outfile, "d[a,b][%d][0,1]=[%g,%g],[%g,%g]\n", i,
+       MYprintf(outfile, "d[a,b][%d][0,1]=[%g,%g],[%g,%g]\n", i,
 	     d_alpha[i][0], d_beta[i][0], d_alpha[i][1], d_beta[i][1]);
 	     } */
  
   /* range gamma hyperprior */
-  if(fix_d) myprintf(outfile, "d prior fixed\n");
+  if(fix_d) MYprintf(outfile, "d prior fixed\n");
   else {
-    myprintf(mystdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+    MYprintf(MYstdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
 	     d_beta_lambda[1]);
   }
